@@ -12,6 +12,13 @@ from gltest_cli.config.general import (
 )
 from gltest_cli.config.types import PluginConfig
 from gltest_cli.config.pytest_context import _pytest_context
+from gltest_cli.config.constants import (
+    DEFAULT_WAIT_INTERVAL,
+    DEFAULT_WAIT_RETRIES,
+    DEFAULT_TEST_WITH_MOCKS,
+    DEFAULT_LEADER_ONLY,
+    CHAINS,
+)
 
 
 def pytest_addoption(parser):
@@ -33,14 +40,14 @@ def pytest_addoption(parser):
     group.addoption(
         "--default-wait-interval",
         action="store",
-        default=3000,
+        default=DEFAULT_WAIT_INTERVAL,
         help="Default interval (ms) between transaction receipt checks",
     )
 
     group.addoption(
         "--default-wait-retries",
         action="store",
-        default=50,
+        default=DEFAULT_WAIT_RETRIES,
         help="Default number of retries for transaction receipt checks",
     )
 
@@ -61,17 +68,24 @@ def pytest_addoption(parser):
     group.addoption(
         "--test-with-mocks",
         action="store_true",
-        default=False,
+        default=DEFAULT_TEST_WITH_MOCKS,
         help="Test with mocks",
     )
 
     group.addoption(
         "--leader-only",
         action="store_true",
-        default=False,
+        default=DEFAULT_LEADER_ONLY,
         help="Run contracts in leader-only mode",
     )
 
+    group.addoption(
+        "--chain-type",
+        action="store",
+        default=None,
+        help=f"Chain type (possible values: {', '.join(CHAINS)})",
+    )
+
 
 def pytest_configure(config):
     try:
@@ -108,6 +122,7 @@ def pytest_configure(config):
         network = config.getoption("--network")
         test_with_mocks = config.getoption("--test-with-mocks")
         leader_only = config.getoption("--leader-only")
+        chain_type = config.getoption("--chain-type")
 
         plugin_config = PluginConfig()
         plugin_config.contracts_dir = (
@@ -122,6 +137,7 @@ def pytest_configure(config):
         plugin_config.network_name = network
         plugin_config.test_with_mocks = test_with_mocks
         plugin_config.leader_only = leader_only
+        plugin_config.chain_type = chain_type
 
         general_config.plugin_config = plugin_config
     except Exception as e:
@@ -148,6 +164,8 @@ def pytest_sessionstart(session):
         # Show available networks including preconfigured ones
         all_networks = general_config.get_networks_keys()
         logger.info(f"  Available networks: {all_networks}")
+        logger.info(f"  Selected chain type: {general_config.get_chain_type()}")
+        logger.info(f"  Available chains: {', '.join(CHAINS)}")
         logger.info(f"  Contracts directory: {general_config.get_contracts_dir()}")
         logger.info(f"  Artifacts directory: {general_config.get_artifacts_dir()}")
         logger.info(f"  Environment: {general_config.user_config.environment}")
