@@ -4,6 +4,7 @@ import re
 from dotenv import load_dotenv
 from pathlib import Path
 from functools import lru_cache
+from dataclasses import replace
 from gltest.accounts import create_accounts
 from gltest_cli.config.constants import (
     GLTEST_CONFIG_FILE,
@@ -12,12 +13,27 @@ from gltest_cli.config.constants import (
     DEFAULT_CONTRACTS_DIR,
     DEFAULT_ARTIFACTS_DIR,
     PRECONFIGURED_NETWORKS,
+    DEFAULT_WAIT_INTERVAL,
+    DEFAULT_WAIT_RETRIES,
+    DEFAULT_TEST_WITH_MOCKS,
+    DEFAULT_LEADER_ONLY,
+    CHAINS,
 )
 from genlayer_py.chains import localnet, studionet, testnet_asimov
 from gltest_cli.config.types import UserConfig, NetworkConfigData, PathConfig
 
 VALID_ROOT_KEYS = ["networks", "paths", "environment"]
-VALID_NETWORK_KEYS = ["id", "url", "accounts", "from", "leader_only"]
+VALID_NETWORK_KEYS = [
+    "id",
+    "url",
+    "accounts",
+    "from",
+    "leader_only",
+    "default_wait_interval",
+    "default_wait_retries",
+    "test_with_mocks",
+    "chain_type",
+]
 VALID_PATHS_KEYS = ["contracts", "artifacts"]
 
 
@@ -32,21 +48,33 @@ def get_default_user_config() -> UserConfig:
             url=localnet.rpc_urls["default"]["http"][0],
             accounts=accounts_private_keys,
             from_account=accounts_private_keys[0],
-            leader_only=False,
+            leader_only=DEFAULT_LEADER_ONLY,
+            default_wait_interval=DEFAULT_WAIT_INTERVAL,
+            default_wait_retries=DEFAULT_WAIT_RETRIES,
+            test_with_mocks=DEFAULT_TEST_WITH_MOCKS,
+            chain_type="localnet",
         ),
         "studionet": NetworkConfigData(
             id=studionet.id,
             url=studionet.rpc_urls["default"]["http"][0],
             accounts=accounts_private_keys,
             from_account=accounts_private_keys[0],
-            leader_only=False,
+            leader_only=DEFAULT_LEADER_ONLY,
+            default_wait_interval=DEFAULT_WAIT_INTERVAL,
+            default_wait_retries=DEFAULT_WAIT_RETRIES,
+            test_with_mocks=DEFAULT_TEST_WITH_MOCKS,
+            chain_type="studionet",
         ),
         "testnet_asimov": NetworkConfigData(
             id=testnet_asimov.id,
             url=testnet_asimov.rpc_urls["default"]["http"][0],
             accounts=None,
             from_account=None,
-            leader_only=False,
+            leader_only=DEFAULT_LEADER_ONLY,
+            default_wait_interval=DEFAULT_WAIT_INTERVAL,
+            default_wait_retries=DEFAULT_WAIT_RETRIES,
+            test_with_mocks=DEFAULT_TEST_WITH_MOCKS,
+            chain_type="testnet_asimov",
         ),
     }
 
@@ -121,7 +149,34 @@ def validate_network_config(network_name: str, network_config: dict):
     ):
         raise ValueError(f"network {network_name} leader_only must be a boolean")
 
-    # For non-preconfigured networks, url and accounts are required
+    if "default_wait_interval" in network_config and not isinstance(
+        network_config["default_wait_interval"], int
+    ):
+        raise ValueError(
+            f"network {network_name} default_wait_interval must be an integer"
+        )
+
+    if "default_wait_retries" in network_config and not isinstance(
+        network_config["default_wait_retries"], int
+    ):
+        raise ValueError(
+            f"network {network_name} default_wait_retries must be an integer"
+        )
+
+    if "test_with_mocks" in network_config and not isinstance(
+        network_config["test_with_mocks"], bool
+    ):
+        raise ValueError(f"network {network_name} test_with_mocks must be a boolean")
+
+    if "chain_type" in network_config:
+        if not isinstance(network_config["chain_type"], str):
+            raise ValueError(f"network {network_name} chain_type must be a string")
+        if network_config["chain_type"] not in CHAINS:
+            raise ValueError(
+                f"network {network_name} chain_type must be one of: {', '.join(CHAINS)}"
+            )
+
+    # For non-preconfigured networks, url, accounts, and chain are required
     if network_name not in PRECONFIGURED_NETWORKS:
         if "id" not in network_config:
             raise ValueError(f"network {network_name} must have an id")
@@ -129,6 +184,10 @@ def validate_network_config(network_name: str, network_config: dict):
             raise ValueError(f"network {network_name} must have a url")
         if "accounts" not in network_config:
             raise ValueError(f"network {network_name} must have accounts")
+        if "chain_type" not in network_config:
+            raise ValueError(
+                f"network {network_name} must have a chain_type. Valid values: localnet, studionet, testnet_asimov"
+            )
 
 
 def validate_raw_user_config(config: dict):
@@ -207,7 +266,10 @@ def _get_overridden_networks(raw_config: dict) -> tuple[dict, str]:
     networks_config = {}
     for network_name, network_config in networks.items():
         if network_name in PRECONFIGURED_NETWORKS:
-            networks_config[network_name] = default_config.networks[network_name]
+            # Clone to avoid mutating the cached default instance
+            networks_config[network_name] = replace(
+                default_config.networks[network_name]
+            )
             if network_config is None:
                 continue
 
@@ -224,19 +286,45 @@ def _get_overridden_networks(raw_config: dict) -> tuple[dict, str]:
                 networks_config[network_name].leader_only = network_config[
                     "leader_only"
                 ]
+            if "default_wait_interval" in network_config:
+                networks_config[network_name].default_wait_interval = network_config[
+                    "default_wait_interval"
+                ]
+            if "default_wait_retries" in network_config:
+                networks_config[network_name].default_wait_retries = network_config[
+                    "default_wait_retries"
+                ]
+            if "test_with_mocks" in network_config:
+                networks_config[network_name].test_with_mocks = network_config[
+                    "test_with_mocks"
+                ]
+            if "chain_type" in network_config:
+                networks_config[network_name].chain_type = network_config["chain_type"]
             continue
 
         url = network_config["url"]
         accounts = network_config["accounts"]
         from_account = network_config.get("from", accounts[0])
         network_id = network_config.get("id")
-        leader_only = network_config.get("leader_only", False)
+        leader_only = network_config.get("leader_only", DEFAULT_LEADER_ONLY)
+        default_wait_interval = network_config.get(
+            "default_wait_interval", DEFAULT_WAIT_INTERVAL
+        )
+        default_wait_retries = network_config.get(
+            "default_wait_retries", DEFAULT_WAIT_RETRIES
+        )
+        test_with_mocks = network_config.get("test_with_mocks", DEFAULT_TEST_WITH_MOCKS)
+        chain_type = network_config["chain_type"]  # Required for custom networks
         networks_config[network_name] = NetworkConfigData(
             id=network_id,
             url=url,
             accounts=accounts,
             from_account=from_account,
             leader_only=leader_only,
+            default_wait_interval=default_wait_interval,
+            default_wait_retries=default_wait_retries,
+            test_with_mocks=test_with_mocks,
+            chain_type=chain_type,
         )
     return networks_config, user_default_network
 
